pub struct DependentPackage {
pub purl: String,
pub requirement: String,
pub scope: String,
pub is_runtime: bool,
pub is_optional: bool,
pub is_resolved: bool,
pub reachable: Reachability,
pub relation: HashSet<Relation>,
pub parents: HashSet<String>,
}Fields
purl: StringDependent package URL A compact purl package URL. Typically when there is an unresolved requirement, there is no version. If the dependency is resolved, the version should be added to the purl
requirement: Stringdependent package version requirement A string defining version(s)requirements. Package-type specific.
scope: Stringdependency scope The scope of this dependency, such as runtime, install, etc. This is package-type specific and is the original scope string.
is_runtime: boolis runtime flag True if this dependency is a runtime dependency.
is_optional: boolis optional flag True if this dependency is an optional dependency’
is_resolved: boolis resolved flag True if this dependency version requirement has been resolved and this dependency url points to an exact version.
reachable: Reachabilityis reachable flag
relation: HashSet<Relation>The relation of this dependency to the top package.
parents: HashSet<String>parents, in purl format