Structs
- Dependent
Package - Lock
Maven Param - Maintainer
- Package
- A package object as represented by either data from one of its different types of package manifests or that of a package instance created from one or more of these package manifests, and files for that package.
- Party
- A party is a person, project or organization related to a package.
- Supported
Type